@@ -232,8 +232,7 @@ def _calculate_feature_stats(feature_list, prepared, serialization_file):  # pyl
         spamwriter = csv.writer(csvfile,
                                 delimiter=';',
                                 quotechar='"',
-                                quoting=csv.QUOTE_MINIMAL,
-                                )
+                                quoting=csv.QUOTE_MINIMAL)
         for feature in feature_list:
             end = start + feature.get_dimension()
             # append the data to the feature class
